class MaxRetryTimeException(Exception):
    def __init__(self, message: str = 'Max retry count reached') -> None: ...

class AllDataCompletedException(Exception):
    def __init__(self, message: str = 'All data completed') -> None: ...
